Advanced
========

This is a section aiming to showcase some problems solved and/or insights gained
using the Axelrod library. Please be the first to submit such a tutorial!

Contents:

.. toctree::
   :maxdepth: 2

   strategy_transformers.rst